from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.api_key_create_request import ApiKeyCreateRequest
from ...models.api_key_create_response import ApiKeyCreateResponse
from ...types import Response


def _get_kwargs(
    *,
    body: ApiKeyCreateRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/v1/service/api-keys",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, ApiKeyCreateResponse]]:
    if response.status_code == 201:
        response_201 = ApiKeyCreateResponse.from_dict(response.json())

        return response_201
    if response.status_code == 400:
        response_400 = cast(Any, None)
        return response_400
    if response.status_code == 401:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == 500:
        response_500 = cast(Any, None)
        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, ApiKeyCreateResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    body: ApiKeyCreateRequest,
) -> Response[Union[Any, ApiKeyCreateResponse]]:
    """Create an API Key

     Creates a new API Key for the authenticated user and returns the token and metadata.

    Args:
        body (ApiKeyCreateRequest):  Example: {'name': 'CI/CD Bot Token', 'permissions':
            {'projects': ['read', 'write'], 'releases': ['read']}, 'ttlDays': 30}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ApiKeyCreateResponse]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    body: ApiKeyCreateRequest,
) -> Optional[Union[Any, ApiKeyCreateResponse]]:
    """Create an API Key

     Creates a new API Key for the authenticated user and returns the token and metadata.

    Args:
        body (ApiKeyCreateRequest):  Example: {'name': 'CI/CD Bot Token', 'permissions':
            {'projects': ['read', 'write'], 'releases': ['read']}, 'ttlDays': 30}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ApiKeyCreateResponse]
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    body: ApiKeyCreateRequest,
) -> Response[Union[Any, ApiKeyCreateResponse]]:
    """Create an API Key

     Creates a new API Key for the authenticated user and returns the token and metadata.

    Args:
        body (ApiKeyCreateRequest):  Example: {'name': 'CI/CD Bot Token', 'permissions':
            {'projects': ['read', 'write'], 'releases': ['read']}, 'ttlDays': 30}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ApiKeyCreateResponse]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    body: ApiKeyCreateRequest,
) -> Optional[Union[Any, ApiKeyCreateResponse]]:
    """Create an API Key

     Creates a new API Key for the authenticated user and returns the token and metadata.

    Args:
        body (ApiKeyCreateRequest):  Example: {'name': 'CI/CD Bot Token', 'permissions':
            {'projects': ['read', 'write'], 'releases': ['read']}, 'ttlDays': 30}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ApiKeyCreateResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
