from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.cloud_integration_request_provider import CloudIntegrationRequestProvider

T = TypeVar("T", bound="CloudIntegrationRequest")


@_attrs_define
class CloudIntegrationRequest:
    """
    Attributes:
        name (str): Customer-defined integration name
        provider (CloudIntegrationRequestProvider): Cloud provider (e.g. aws, gcp, azure)
        region (str): AWS region for integration resources (e.g. us-east-1)
    """

    name: str
    provider: CloudIntegrationRequestProvider
    region: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        provider = self.provider.value

        region = self.region

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "provider": provider,
                "region": region,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        provider = CloudIntegrationRequestProvider(d.pop("provider"))

        region = d.pop("region")

        cloud_integration_request = cls(
            name=name,
            provider=provider,
            region=region,
        )

        cloud_integration_request.additional_properties = d
        return cloud_integration_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
